==> hippoagentsdk-0.0.2-sources.jar: com/hippoagent/fragments/AllFragment.java <==
package com.hippoagent.fragments;//package com.fuguagent.fragments;
//
//import android.app.Activity;
//import android.content.Intent;
//import android.os.Bundle;
//import androidx.annotation.Nullable;
//import androidx.fragment.app.Fragment;
//import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;
//import androidx.recyclerview.widget.DefaultItemAnimator;
//import androidx.recyclerview.widget.LinearLayoutManager;
//import androidx.recyclerview.widget.RecyclerView;
//import android.view.LayoutInflater;
//import android.view.View;
//import android.view.ViewGroup;
//import android.widget.LinearLayout;
//
//import com.fuguagent.MyApplication;
//import com.fuguagent.R;
//import com.fuguagent.activities.FuguChatActivity;
//import com.fuguagent.activities.MainActivity;
//import com.fuguagent.adapters.AllChatAdapter;
//import com.fuguagent.model.Conversation;
//import com.fuguagent.com.hippoagentsdk.utils.Constants;
//import com.fuguagent.com.hippoagentsdk.utils.Log;
//import com.google.gson.Gson;
//
//import java.util.ArrayList;
//import java.util.List;
//
///**
// * Created by ankit on 29/05/17.
// */
//
//public class AllFragment extends Fragment implements SwipeRefreshLayout.OnRefreshListener{
//
//    private View root;
//    private SwipeRefreshLayout srLayout;
//    private RecyclerView rvAll;
//    private AllChatAdapter allChatAdapter;
//    private ArrayList<Object> allList = new ArrayList<>();
//    LinearLayoutManager layoutManager;
//    private int pastVisiblesItems, visibleItemCount, totalItemCount;
//    private LinearLayout llNoConversation;
//
//    public AllFragment() {
//    }
//
//    @Nullable
//    @Override
//    public View onCreateView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
//        root = inflater.inflate(R.layout.all_fragment, container, false);
//        return root;
//    }
//
//    @Override
//    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
//        super.onViewCreated(view, savedInstanceState);
//        srLayout = (SwipeRefreshLayout) view.findViewById(R.id.srLayout);
//        srLayout.setOnRefreshListener(this);
//        srLayout.setColorSchemeResources(R.color.white);
//        srLayout.setProgressBackgroundColorSchemeResource(R.color.colorPrimary);
//        srLayout.setSize(SwipeRefreshLayout.DEFAULT);
//        llNoConversation = (LinearLayout) root.findViewById(R.id.llNoConversation);
//        rvAll = (RecyclerView) view.findViewById(R.id.rvAll);
//        layoutManager = new LinearLayoutManager(getActivity());
//        rvAll.setLayoutManager(layoutManager);
//        rvAll.setItemAnimator(new DefaultItemAnimator());
//        rvAll.setHasFixedSize(false);
//
//
//
//        allChatAdapter = new AllChatAdapter(allList, getActivity(), new AllChatAdapter.Callback() {
//            @Override
//            public void onClick(int position, Conversation conversation) {
//                conversation.setUnreadCount(0);
//                allChatAdapter.notifyDataSetChanged();
//                setMyChatConversationCount(conversation);
//                Intent chatIntent = new Intent(getActivity(), FuguChatActivity.class);
//                chatIntent.putExtra(Constants.CONVERSATION, new Gson().toJson(conversation, Conversation.class));
//                startActivityForResult(chatIntent, 100);
////                startActivity(new Intent(getActivity(), FuguChatActivity.class));
//            }
//        }, rvAll);
//        rvAll.setAdapter(allChatAdapter);
//
//
//        if(allList.size() == 0){
//            llNoConversation.setVisibility(View.VISIBLE);
//        } else{
//            llNoConversation.setVisibility(View.GONE);
//        }
//        rvAll.addOnScrollListener(new RecyclerView.OnScrollListener() {
//            @Override
//            public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
//                super.onScrollStateChanged(recyclerView, newState);
//            }
//
//            @Override
//            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
//                //To implement Pagination
//                if (dy > 0) {
//                    visibleItemCount = layoutManager.getChildCount();
//                    totalItemCount = layoutManager.getItemCount();
//                    pastVisiblesItems = layoutManager.findFirstVisibleItemPosition();
//
//                    if(!((MainActivity)getActivity()).getHomeFragment().isPagingApiInProgress()) {
//                        if ((visibleItemCount + pastVisiblesItems) >= totalItemCount) {
//                            fetchNextPage();
//                        }
//                    }
//                }
//            }
//        });
//    }
//
//    private void setMyChatConversationCount(Conversation conversationCount){
//        /*for(Conversation conversation : ((MainActivity)getActivity()).getHomeFragment().getMyChatList()){
//            if(conversation.getChannelId().equals(conversationCount.getChannelId())){
//                conversation.setUnreadCount(0);
//                break;
//            }
//        }*/
//    }
//
//    @Override
//    public void onActivityResult(int requestCode, int resultCode, Intent data) {
//        super.onActivityResult(requestCode, resultCode, data);
//        Log.v("onActivityResult", "enter");
//        if(requestCode == 100){
//            if(resultCode == Activity.RESULT_OK){
////                GetConversationResponse.Conversation conversation = new Gson().fromJson(data.getStringExtra(Constants.RESULT), GetConversationResponse.Conversation.class);
////                for(Object obj : allList){
////                    if(obj instanceof GetConversationResponse.Conversation &&
////                            ((GetConversationResponse.Conversation)obj).getChannelId().equals(conversation.getChannelId())){
////                        ((GetConversationResponse.Conversation)obj).setMessage(conversation.getMessage());
////                        allChatAdapter.notifyDataSetChanged();
////                        break;
////                    }
////                }
////                ((MainActivity)getActivity()).getHomeFragment().apiGetConversation(((MainActivity)getActivity()).getMessageMod()
////                        , ConversationMode.ALL.getOrdinal(), 0, false);
//            }
//        }
//    }
//
//    public SwipeRefreshLayout getSrLayout() {
//        return srLayout;
//    }
//
//    private void fetchNextPage() {
//        ((MainActivity)getActivity()).getHomeFragment().setPagingApiInProgress(true);
//        toggleProgressBarVisibility(true);
//        int pageStart = allList.size();
//        if (allList.contains(progressBarItem)) {
//            pageStart = allList.size();
//        }
//        ((MainActivity)getActivity()).getHomeFragment().apiGetConversation(String.valueOf(MyApplication.getInstance().getUserData().getUserId()),((MainActivity)getActivity()).getStatusIntArray()
//                , ((MainActivity)getActivity()).getTypeIntArray(), ((MainActivity)getActivity()).getLabelsIntArray(), pageStart, true, true,true);
//    }
//
//    private AllChatAdapter.ProgressBarItem progressBarItem;
//
//    public void toggleProgressBarVisibility(boolean isVisible) {
//        if (isVisible) {
//            if (progressBarItem == null) {
//                progressBarItem = new AllChatAdapter.ProgressBarItem();
//            }
//            if (!allList.contains(progressBarItem)) {
//                allList.add(progressBarItem);
//                allChatAdapter.notifyItemInserted(allList.size() - 1);
//            }
//        } else {
//            if (progressBarItem != null && allList.contains(progressBarItem)) {
//                allList.remove(progressBarItem);
//                allChatAdapter.notifyItemRemoved(allList.size() - 1);
//            }
//        }
//    }
//
//    private ArrayList<Object> getAdapterList(List<Conversation> allChatDetailList) {
//        if (allList == null) {
//            allList = new ArrayList<>();
//        }
//        allList.clear();
//
//        if (allChatDetailList != null && allChatDetailList.size() > 0) {
//            allList.addAll(allChatDetailList);
//        }
//        return allList;
//    }
//
//    public void setAllChatData(ArrayList<Conversation> allChatData, boolean isPagination){
//        if(!isPagination) {
//            allList.clear();
//        }
//        allList.addAll(allChatData);
//        if(getView() != null && allChatAdapter != null) {
//            getActivity().runOnUiThread(new Runnable() {
//                @Override
//                public void run() {
//                    allChatAdapter.notifyDataSetChanged();
//                }
//            });
//        }
//
//        if(llNoConversation != null) {
//            if (allList.size() == 0) {
//                llNoConversation.setVisibility(View.VISIBLE);
//            } else {
//                llNoConversation.setVisibility(View.GONE);
//            }
//        }
//    }
//
//    @Override
//    public void onRefresh() {
//        ((MainActivity)getActivity()).getHomeFragment().apiGetConversation(String.valueOf(MyApplication.getInstance().getUserData().getUserId()),((MainActivity)getActivity()).getStatusIntArray()
//                , ((MainActivity)getActivity()).getTypeIntArray(), ((MainActivity)getActivity()).getLabelsIntArray(), 1, false, false,true);
//    }
//}

==> hippoagentsdk-0.1.3-sources.jar: com/hippoagent/fragments/AllFragment.java <==
package com.hippoagent.fragments;//package com.fuguagent.fragments;
//
//import android.app.Activity;
//import android.content.Intent;
//import android.os.Bundle;
//import androidx.annotation.Nullable;
//import androidx.fragment.app.Fragment;
//import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;
//import androidx.recyclerview.widget.DefaultItemAnimator;
//import androidx.recyclerview.widget.LinearLayoutManager;
//import androidx.recyclerview.widget.RecyclerView;
//import android.view.LayoutInflater;
//import android.view.View;
//import android.view.ViewGroup;
//import android.widget.LinearLayout;
//
//import com.fuguagent.HippoApplication;
//import com.fuguagent.R;
//import com.fuguagent.activities.FuguChatActivity;
//import com.fuguagent.activities.MainActivity;
//import com.fuguagent.adapters.AllChatAdapter;
//import com.fuguagent.model.Conversation;
//import com.fuguagent.com.hippoagentsdk.utils.Constants;
//import com.fuguagent.com.hippoagentsdk.utils.Log;
//import com.google.gson.Gson;
//
//import java.util.ArrayList;
//import java.util.List;
//
///**
// * Created by ankit on 29/05/17.
// */
//
//public class AllFragment extends Fragment implements SwipeRefreshLayout.OnRefreshListener{
//
//    private View root;
//    private SwipeRefreshLayout srLayout;
//    private RecyclerView rvAll;
//    private AllChatAdapter allChatAdapter;
//    private ArrayList<Object> allList = new ArrayList<>();
//    LinearLayoutManager layoutManager;
//    private int pastVisiblesItems, visibleItemCount, totalItemCount;
//    private LinearLayout llNoConversation;
//
//    public AllFragment() {
//    }
//
//    @Nullable
//    @Override
//    public View onCreateView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
//        root = inflater.inflate(R.layout.all_fragment, container, false);
//        return root;
//    }
//
//    @Override
//    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
//        super.onViewCreated(view, savedInstanceState);
//        srLayout = (SwipeRefreshLayout) view.findViewById(R.id.srLayout);
//        srLayout.setOnRefreshListener(this);
//        srLayout.setColorSchemeResources(R.color.white);
//        srLayout.setProgressBackgroundColorSchemeResource(R.color.colorPrimary);
//        srLayout.setSize(SwipeRefreshLayout.DEFAULT);
//        llNoConversation = (LinearLayout) root.findViewById(R.id.llNoConversation);
//        rvAll = (RecyclerView) view.findViewById(R.id.rvAll);
//        layoutManager = new LinearLayoutManager(getActivity());
//        rvAll.setLayoutManager(layoutManager);
//        rvAll.setItemAnimator(new DefaultItemAnimator());
//        rvAll.setHasFixedSize(false);
//
//
//
//        allChatAdapter = new AllChatAdapter(allList, getActivity(), new AllChatAdapter.Callback() {
//            @Override
//            public void onClick(int position, Conversation conversation) {
//                conversation.setUnreadCount(0);
//                allChatAdapter.notifyDataSetChanged();
//                setMyChatConversationCount(conversation);
//                Intent chatIntent = new Intent(getActivity(), FuguChatActivity.class);
//                chatIntent.putExtra(Constants.CONVERSATION, new Gson().toJson(conversation, Conversation.class));
//                startActivityForResult(chatIntent, 100);
////                startActivity(new Intent(getActivity(), FuguChatActivity.class));
//            }
//        }, rvAll);
//        rvAll.setAdapter(allChatAdapter);
//
//
//        if(allList.size() == 0){
//            llNoConversation.setVisibility(View.VISIBLE);
//        } else{
//            llNoConversation.setVisibility(View.GONE);
//        }
//        rvAll.addOnScrollListener(new RecyclerView.OnScrollListener() {
//            @Override
//            public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
//                super.onScrollStateChanged(recyclerView, newState);
//            }
//
//            @Override
//            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
//                //To implement Pagination
//                if (dy > 0) {
//                    visibleItemCount = layoutManager.getChildCount();
//                    totalItemCount = layoutManager.getItemCount();
//                    pastVisiblesItems = layoutManager.findFirstVisibleItemPosition();
//
//                    if(!((MainActivity)getActivity()).getHomeFragment().isPagingApiInProgress()) {
//                        if ((visibleItemCount + pastVisiblesItems) >= totalItemCount) {
//                            fetchNextPage();
//                        }
//                    }
//                }
//            }
//        });
//    }
//
//    private void setMyChatConversationCount(Conversation conversationCount){
//        /*for(Conversation conversation : ((MainActivity)getActivity()).getHomeFragment().getMyChatList()){
//            if(conversation.getChannelId().equals(conversationCount.getChannelId())){
//                conversation.setUnreadCount(0);
//                break;
//            }
//        }*/
//    }
//
//    @Override
//    public void onActivityResult(int requestCode, int resultCode, Intent data) {
//        super.onActivityResult(requestCode, resultCode, data);
//        Log.v("onActivityResult", "enter");
//        if(requestCode == 100){
//            if(resultCode == Activity.RESULT_OK){
////                GetConversationResponse.Conversation conversation = new Gson().fromJson(data.getStringExtra(Constants.RESULT), GetConversationResponse.Conversation.class);
////                for(Object obj : allList){
////                    if(obj instanceof GetConversationResponse.Conversation &&
////                            ((GetConversationResponse.Conversation)obj).getChannelId().equals(conversation.getChannelId())){
////                        ((GetConversationResponse.Conversation)obj).setMessage(conversation.getMessage());
////                        allChatAdapter.notifyDataSetChanged();
////                        break;
////                    }
////                }
////                ((MainActivity)getActivity()).getHomeFragment().apiGetConversation(((MainActivity)getActivity()).getMessageMod()
////                        , ConversationMode.ALL.getOrdinal(), 0, false);
//            }
//        }
//    }
//
//    public SwipeRefreshLayout getSrLayout() {
//        return srLayout;
//    }
//
//    private void fetchNextPage() {
//        ((MainActivity)getActivity()).getHomeFragment().setPagingApiInProgress(true);
//        toggleProgressBarVisibility(true);
//        int pageStart = allList.size();
//        if (allList.contains(progressBarItem)) {
//            pageStart = allList.size();
//        }
//        ((MainActivity)getActivity()).getHomeFragment().apiGetConversation(String.valueOf(HippoApplication.getInstance().getUserData().getUserId()),((MainActivity)getActivity()).getStatusIntArray()
//                , ((MainActivity)getActivity()).getTypeIntArray(), ((MainActivity)getActivity()).getLabelsIntArray(), pageStart, true, true,true);
//    }
//
//    private AllChatAdapter.ProgressBarItem progressBarItem;
//
//    public void toggleProgressBarVisibility(boolean isVisible) {
//        if (isVisible) {
//            if (progressBarItem == null) {
//                progressBarItem = new AllChatAdapter.ProgressBarItem();
//            }
//            if (!allList.contains(progressBarItem)) {
//                allList.add(progressBarItem);
//                allChatAdapter.notifyItemInserted(allList.size() - 1);
//            }
//        } else {
//            if (progressBarItem != null && allList.contains(progressBarItem)) {
//                allList.remove(progressBarItem);
//                allChatAdapter.notifyItemRemoved(allList.size() - 1);
//            }
//        }
//    }
//
//    private ArrayList<Object> getAdapterList(List<Conversation> allChatDetailList) {
//        if (allList == null) {
//            allList = new ArrayList<>();
//        }
//        allList.clear();
//
//        if (allChatDetailList != null && allChatDetailList.size() > 0) {
//            allList.addAll(allChatDetailList);
//        }
//        return allList;
//    }
//
//    public void setAllChatData(ArrayList<Conversation> allChatData, boolean isPagination){
//        if(!isPagination) {
//            allList.clear();
//        }
//        allList.addAll(allChatData);
//        if(getView() != null && allChatAdapter != null) {
//            getActivity().runOnUiThread(new Runnable() {
//                @Override
//                public void run() {
//                    allChatAdapter.notifyDataSetChanged();
//                }
//            });
//        }
//
//        if(llNoConversation != null) {
//            if (allList.size() == 0) {
//                llNoConversation.setVisibility(View.VISIBLE);
//            } else {
//                llNoConversation.setVisibility(View.GONE);
//            }
//        }
//    }
//
//    @Override
//    public void onRefresh() {
//        ((MainActivity)getActivity()).getHomeFragment().apiGetConversation(String.valueOf(HippoApplication.getInstance().getUserData().getUserId()),((MainActivity)getActivity()).getStatusIntArray()
//                , ((MainActivity)getActivity()).getTypeIntArray(), ((MainActivity)getActivity()).getLabelsIntArray(), 1, false, false,true);
//    }
//}
